@@ -41,12 +41,12 @@
 match_wav_case <- function(X, path = NULL, output = "data.frame", verbose = TRUE){
 
 # get path if not provided    
-if(is.null(path)) path <- getwd()
+if (is.null(path)) path <- getwd()
 
 # list  wav files in path
 wvs <- list.files(path = path, pattern = "\\.wav$", ignore.case = TRUE)
 
-if(length(wvs) == 0) stop("no sound files are found in working directory")
+if (length(wvs) == 0) stop("no sound files are found in working directory")
 
 # remove extension for both names in selec.table and wavs
 sf.no.ext <- gsub(".wav", "", X$sound.files, ignore.case = TRUE)
@@ -56,13 +56,10 @@ wvs.no.ext <- gsub(".wav", "", wvs, ignore.case = TRUE)
 fix.sf <- sapply(1:nrow(X), function(i) ifelse(sf.no.ext[i] %in% wvs.no.ext, wvs[wvs.no.ext == sf.no.ext[i]], sf.no.ext[i]))
 
 # warning if not all find found
-if(length(which(!sf.no.ext %in% wvs.no.ext)) > 0 & verbose) cat(paste("the following files were not found:", paste(unique(sf.no.ext[which(!sf.no.ext %in% wvs.no.ext)]), collapse = "/")))
+if (any(!sf.no.ext %in% wvs.no.ext) & verbose) cat(paste("the following files were not found:", paste(unique(sf.no.ext[!sf.no.ext %in% wvs.no.ext]), collapse = "/")))
 
 # overwrite sound.files column with fix names
 X$sound.files <- fix.sf
 
-if(output == "data.frame")  return(X) else return(fix.sf)
-}
-
-
-
+if (output == "data.frame")  return(X) else return(fix.sf)
+}
\ No newline at end of file
